summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--README6
-rw-r--r--apps/Jamfile20
-rw-r--r--apps/macosx/FzView.app/Contents/Info.plist (renamed from apps/macosx/GhostPDF.app/Contents/Info.plist)0
-rw-r--r--apps/macosx/FzView.app/Contents/PkgInfo (renamed from apps/macosx/GhostPDF.app/Contents/PkgInfo)0
-rw-r--r--apps/macosx/FzView.app/Contents/Resources/English.lproj/InfoPlist.strings (renamed from apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/InfoPlist.strings)0
-rw-r--r--apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/classes.nib (renamed from apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/classes.nib)0
-rw-r--r--apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/info.nib (renamed from apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/info.nib)7
-rw-r--r--apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/objects.xib (renamed from apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/objects.xib)8
-rw-r--r--apps/macosx/FzView.app/Contents/Resources/macpdf.icns (renamed from apps/macosx/GhostPDF.app/Contents/Resources/macpdf.icns)bin31574 -> 31574 bytes
-rw-r--r--apps/mozilla/moz_winres.rc6
-rw-r--r--apps/unix/x11pdf.c6
-rw-r--r--apps/windows/winmain.c26
-rw-r--r--apps/windows/winres.rc4
13 files changed, 41 insertions, 42 deletions
diff --git a/README b/README
index 6dd42268..3fe47f14 100644
--- a/README
+++ b/README
@@ -3,11 +3,11 @@ README for the Fitz distribution.
Fitz is a graphics library.
MuPDF is a PDF parsing and manipulation library.
Samus is a Metro parser.
-GhostPDF is a PDF viewer using MuPDF and Fitz.
+FzView is a PDF and Metro viewer application.
For Windows, there is also a Mozilla plugin version of the viewer.
-GhostPDF has three ports: X11, Windows and Carbon.
-The Carbon port is broken, so don't bother trying it.
+The Viewer has three ports: X11, Windows and Carbon.
+The Carbon port is rotting, so don't bother trying it.
This code is under the same licensing scheme as Ghostscript.
AFPL and one year or major release later GPL.
diff --git a/apps/Jamfile b/apps/Jamfile
index a2452a4f..4accf75a 100644
--- a/apps/Jamfile
+++ b/apps/Jamfile
@@ -36,7 +36,7 @@ if $(OS) = MINGW
{
SubDir TOP apps windows ;
- Main ghostpdf :
+ Main fzview :
winmain.c
winres.rc
;
@@ -44,26 +44,26 @@ if $(OS) = MINGW
WINLIBS = -lgdi32 -lcomdlg32 ;
if $(BUILD) = release { WINLIBS += -mwindows ; }
- LinkLibraries ghostpdf : libpdfapp $(FITZLIBS) ;
+ LinkLibraries fzview : libpdfapp $(FITZLIBS) ;
- LINKLIBS on ghostpdf$(SUFEXE) = $(LINKLIBS) $(WINLIBS) ;
+ LINKLIBS on fzview$(SUFEXE) = $(LINKLIBS) $(WINLIBS) ;
- InstallBin $(BINDIR) : ghostpdf$(SUFEXE) ;
+ InstallBin $(BINDIR) : fzview$(SUFEXE) ;
}
if $(HAVE_X11) = yes
{
SubDir TOP apps unix ;
- Main ghostpdf : x11pdf.c ximage.c ;
- LinkLibraries ghostpdf : libpdfapp $(FITZLIBS) ;
- LINKLIBS on ghostpdf$(SUFEXE) = $(LINKLIBS) -lX11 -lXext ;
+ Main fzview : x11pdf.c ximage.c ;
+ LinkLibraries fzview : libpdfapp $(FITZLIBS) ;
+ LINKLIBS on fzview$(SUFEXE) = $(LINKLIBS) -lX11 -lXext ;
}
-if $(OS) = MACOSX
+if $(OS) = noMACOSX
{
SubDir TOP apps macosx ;
- MACBUNDLE = GhostPDF.app ;
+ MACBUNDLE = FzView.app ;
XCopy
$(MACBUNDLE)/Contents/Info.plist
@@ -77,7 +77,7 @@ if $(OS) = MACOSX
$(MACBUNDLE)/Contents/Resources/macpdf.icns
;
- MACPDF = $(MACBUNDLE)/Contents/MacOS/ghostpdf ;
+ MACPDF = $(MACBUNDLE)/Contents/MacOS/fzview ;
MkDir $(ALL_LOCATE_TARGET)/$(MACPDF:D) ;
Depends $(MACPDF) : $(ALL_LOCATE_TARGET)/$(MACPDF:D) ;
Main $(MACPDF) : macpdf.c ;
diff --git a/apps/macosx/GhostPDF.app/Contents/Info.plist b/apps/macosx/FzView.app/Contents/Info.plist
index 5b7681b2..5b7681b2 100644
--- a/apps/macosx/GhostPDF.app/Contents/Info.plist
+++ b/apps/macosx/FzView.app/Contents/Info.plist
diff --git a/apps/macosx/GhostPDF.app/Contents/PkgInfo b/apps/macosx/FzView.app/Contents/PkgInfo
index bd04210f..bd04210f 100644
--- a/apps/macosx/GhostPDF.app/Contents/PkgInfo
+++ b/apps/macosx/FzView.app/Contents/PkgInfo
diff --git a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/InfoPlist.strings b/apps/macosx/FzView.app/Contents/Resources/English.lproj/InfoPlist.strings
index f3bc1127..f3bc1127 100644
--- a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/InfoPlist.strings
+++ b/apps/macosx/FzView.app/Contents/Resources/English.lproj/InfoPlist.strings
diff --git a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/classes.nib b/apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/classes.nib
index ea58db11..ea58db11 100644
--- a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/classes.nib
+++ b/apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/classes.nib
diff --git a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/info.nib b/apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/info.nib
index 40806e42..611a192f 100644
--- a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/info.nib
+++ b/apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/info.nib
@@ -3,17 +3,16 @@
<plist version="1.0">
<dict>
<key>IBDocumentLocation</key>
- <string>64 19 356 240 0 0 1152 746 </string>
+ <string>54 19 356 240 0 0 1024 746 </string>
<key>IBEditorPositions</key>
<dict>
<key>29</key>
- <string>17 273 236 44 0 0 1152 746 </string>
+ <string>15 273 236 44 0 0 1024 746 </string>
</dict>
<key>IBFramework Version</key>
- <string>364.0</string>
+ <string>349.0</string>
<key>IBOpenObjects</key>
<array>
- <integer>231</integer>
<integer>166</integer>
<integer>29</integer>
</array>
diff --git a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/objects.xib b/apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/objects.xib
index dba01432..143a0dd0 100644
--- a/apps/macosx/GhostPDF.app/Contents/Resources/English.lproj/main.nib/objects.xib
+++ b/apps/macosx/FzView.app/Contents/Resources/English.lproj/main.nib/objects.xib
@@ -9,13 +9,13 @@
<string name="title">GhostPDF</string>
<array count="4" name="items">
<object class="IBCarbonMenuItem" id="185">
- <string name="title">GhostPDF</string>
+ <string name="title">MuView</string>
<object name="submenu" class="IBCarbonMenu" id="184">
- <string name="title">GhostPDF</string>
+ <string name="title">MuView</string>
<array count="1" name="items">
<object class="IBCarbonMenuItem" id="187">
<boolean name="updateSingleItem">TRUE</boolean>
- <string name="title">About GhostPDF</string>
+ <string name="title">About MuView</string>
<int name="keyEquivalentModifier">0</int>
<ostype name="command">abou</ostype>
</object>
@@ -399,7 +399,7 @@
<object class="IBCarbonStaticText" id="233">
<string name="bounds">20 20 36 234 </string>
<string name="viewFrame">20 20 214 16 </string>
- <string name="title">This PDF document is encrypted.</string>
+ <string name="title">This document is encrypted.</string>
</object>
<object class="IBCarbonStaticText" id="234">
<string name="bounds">50 32 66 146 </string>
diff --git a/apps/macosx/GhostPDF.app/Contents/Resources/macpdf.icns b/apps/macosx/FzView.app/Contents/Resources/macpdf.icns
index d11b8be1..d11b8be1 100644
--- a/apps/macosx/GhostPDF.app/Contents/Resources/macpdf.icns
+++ b/apps/macosx/FzView.app/Contents/Resources/macpdf.icns
Binary files differ
diff --git a/apps/mozilla/moz_winres.rc b/apps/mozilla/moz_winres.rc
index 189d3aea..da421383 100644
--- a/apps/mozilla/moz_winres.rc
+++ b/apps/mozilla/moz_winres.rc
@@ -1,5 +1,5 @@
//
-// GhostPDF Plugin description
+// MuPDF Plugin description
//
1 VERSIONINFO
@@ -9,9 +9,9 @@ BEGIN
BEGIN
BLOCK "040904e4"
BEGIN
- VALUE "ProductName", "GhostPDF Plug-in\0"
+ VALUE "ProductName", "MuPDF Plug-in\0"
VALUE "OriginalFilename", "npmupdf.dll\0"
- VALUE "FileDescription", "The GhostPDF plugin allows you to browse PDF files with a simple light-weight scrolling interface.<br>See <a href=""http://ghostpdf.com/new.html"">ghostpdf.com</a> for more information.\0"
+ VALUE "FileDescription", "The MuPDF plugin allows you to browse PDF files with a simple light-weight scrolling interface.<br>See <a href=""http://ghostscript.com/~tor/software/fitz.html">ghostscript.com</a> for more information.\0"
VALUE "MIMEType", "application/pdf|application/x-mupdf\0"
VALUE "FileExtents", "pdf|foo"
VALUE "FileOpenName", "Acrobat PDF File|Acrobat PDF File"
diff --git a/apps/unix/x11pdf.c b/apps/unix/x11pdf.c
index 72bccd69..5941d4d0 100644
--- a/apps/unix/x11pdf.c
+++ b/apps/unix/x11pdf.c
@@ -47,12 +47,12 @@ static pdfapp_t gapp;
void winwarn(pdfapp_t *app, char *msg)
{
- fprintf(stderr, "ghostpdf: %s\n", msg);
+ fprintf(stderr, "fzview: %s\n", msg);
}
void winerror(pdfapp_t *app, char *msg)
{
- fprintf(stderr, "ghostpdf: %s\n", msg);
+ fprintf(stderr, "fzview: %s\n", msg);
exit(1);
}
@@ -391,7 +391,7 @@ void onmouse(int x, int y, int btn, int modifiers, int state)
void usage(void)
{
- fprintf(stderr, "usage: ghostpdf [-d password] [-z zoom] [-p pagenumber] file.pdf\n");
+ fprintf(stderr, "usage: fzview [-d password] [-z zoom] [-p pagenumber] file.pdf\n");
exit(1);
}
diff --git a/apps/windows/winres.rc b/apps/windows/winres.rc
index dbe41204..cad44a1f 100644
--- a/apps/windows/winres.rc
+++ b/apps/windows/winres.rc
@@ -4,7 +4,7 @@ IDI_ICONDOC ICON "gsdoc.ico"
IDD_DLOGPASS DIALOG 50, 50, 204, 60
//STYLE DS_MODALFRAME | WS_POPUP
STYLE 128 | 0x80000000
-CAPTION " GhostPDF: Password "
+CAPTION " FzView: Password "
FONT 8, "MS Shell Dlg"
BEGIN
EDITTEXT 3, 57,20,140,12, 32
@@ -52,7 +52,7 @@ END
IDD_DLOGABOUT DIALOG 50, 50, 200, 210
STYLE 128 | 0x80000000
-CAPTION " About GhostPDF "
+CAPTION " About FzView "
FONT 8, "MS Shell Dlg"
BEGIN
DEFPUSHBUTTON "Okay", 1, 200-10-50,210-7-14,50,14, 0x50010001
diff --git a/apps/windows/winmain.c b/apps/windows/winmain.c
index bc731a4e..cd06d41a 100644
--- a/apps/windows/winmain.c
+++ b/apps/windows/winmain.c
@@ -15,7 +15,7 @@ static HDC hdc;
static HBRUSH bgbrush;
static HBRUSH shbrush;
static BITMAPINFO *dibinf;
-static TCHAR szAppName[] = TEXT("ghostpdf");
+static TCHAR szAppName[] = TEXT("fzview");
static HCURSOR arrowcurs, handcurs, waitcurs;
static LRESULT CALLBACK windproc(HWND, UINT, WPARAM, LPARAM);
@@ -26,7 +26,7 @@ static int justcopied = 0;
static pdfapp_t gapp;
/*
* Associate GhostPDF with PDF files.
*/
void associate(char *argv0)
@@ -43,22 +43,22 @@ void associate(char *argv0)
KEY_WRITE, NULL, &key, &disp))
return;
- if (RegSetValueEx(key, "", 0, REG_SZ, "GhostPDF", strlen("GhostPDF")+1))
+ if (RegSetValueEx(key, "", 0, REG_SZ, "FzView", strlen("FzView")+1))
return;
RegCloseKey(key);
- /* HKEY_CLASSES_ROOT\GhostPDF */
+ /* HKEY_CLASSES_ROOT\FzView */
if (RegCreateKeyEx(HKEY_CLASSES_ROOT,
- "GhostPDF", 0, NULL, REG_OPTION_NON_VOLATILE,
+ "FzView", 0, NULL, REG_OPTION_NON_VOLATILE,
KEY_WRITE, NULL, &key, &disp))
return;
if (RegSetValueEx(key, "", 0, REG_SZ, name, strlen(name)+1))
return;
- /* HKEY_CLASSES_ROOT\GhostPDF\DefaultIcon */
+ /* HKEY_CLASSES_ROOT\FzView\DefaultIcon */
if (RegCreateKeyEx(key,
"DefaultIcon", 0, NULL, REG_OPTION_NON_VOLATILE,
@@ -71,7 +71,7 @@ void associate(char *argv0)
RegCloseKey(kicon);
- /* HKEY_CLASSES_ROOT\GhostPDF\Shell\Open\Command */
+ /* HKEY_CLASSES_ROOT\FzView\Shell\Open\Command */
if (RegCreateKeyEx(key,
"shell", 0, NULL, REG_OPTION_NON_VOLATILE,
@@ -103,12 +103,12 @@ void associate(char *argv0)
void winwarn(pdfapp_t *app, char *msg)
{
- MessageBoxA(hwnd, msg, "GhostPDF: Warning", MB_ICONWARNING);
+ MessageBoxA(hwnd, msg, "FzView: Warning", MB_ICONWARNING);
}
void winerror(pdfapp_t *app, char *msg)
{
- MessageBoxA(hwnd, msg, "GhostPDF: Error", MB_ICONERROR);
+ MessageBoxA(hwnd, msg, "FzView: Error", MB_ICONERROR);
exit(1);
}
@@ -122,7 +122,7 @@ int winfilename(char *buf, int len)
ofn.lpstrFile = buf;
ofn.nMaxFile = len;
ofn.lpstrInitialDir = NULL;
- ofn.lpstrTitle = "GhostPDF: Open PDF file";
+ ofn.lpstrTitle = "FzView: Open PDF file";
ofn.lpstrFilter = "PDF Files (*.pdf)\0*.pdf\0All Files\0*\0\0";
ofn.Flags = OFN_FILEMUSTEXIST|OFN_HIDEREADONLY;
return GetOpenFileName(&ofn);
@@ -260,7 +260,7 @@ dlogaboutproc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
{
case WM_INITDIALOG:
SetDlgItemTextA(hwnd, 0x10, gapp.filename);
- SetDlgItemTextA(hwnd, 2, "GhostPDF is Copyright (C) 2005 artofcode, LLC");
+ SetDlgItemTextA(hwnd, 2, "FzView is Copyright (C) 2005 artofcode, LLC");
SetDlgItemTextA(hwnd, 3, pdfapp_usage(&gapp));
return TRUE;
case WM_COMMAND:
@@ -340,11 +340,11 @@ void winopen()
hdc = NULL;
- SetWindowTextA(hwnd, "GhostPDF");
+ SetWindowTextA(hwnd, "FzView");
menu = GetSystemMenu(hwnd, 0);
AppendMenu(menu, MF_SEPARATOR, 0, NULL);
- AppendMenu(menu, MF_STRING, ID_ABOUT, "About GhostPDF...");
+ AppendMenu(menu, MF_STRING, ID_ABOUT, "About FzView...");
AppendMenu(menu, MF_STRING, ID_DOCINFO, "Document Properties...");
SetCursor(arrowcurs);
@@ -26,7 +26,7 @@ static int justcopied = 0;
static pdfapp_t gapp;
/*
- * Associate GhostPDF with PDF files.
+ * Associate FzView with PDF files.
*/
void associate(char *argv0)